#!/bin/bash

tmp_cache="tmp-cache"

echo ""

if [ "x$GSDL3SRCHOME" = "x" ] ; then
   echo "Environment variable GSDL3SRCHOME not set." 1>&2
   echo "Have you sourced ./gs3-setup.sh?" 1>&2
   exit 1
fi
   
if [ ! -d $tmp_cache ] ; then
    echo "Making temporary directory:"
    echo "  $tmp_cache"
    mkdir $tmp_cache
else
    echo "Removing existing content from:"
    echo "  $tmp_cache"
    /bin/rm -rf $tmp_cache/*
fi

echo "Copying to '$tmp_cache' then exploding:"

f="local--esc-mir-gold.json"
echo "  spotify-musicbrainz/$f -> $tmp_cache/sparqlresults-$f"    
/bin/cp "spotify-musicbrainz/$f" "$tmp_cache/sparqlresults-$f"

explode_metadata_database.pl \
    -collectdir $GSDL3SRCHOME/web/sites/eurovision-lod/collect \
    -collection eurovision \
    -plugin_options "-metadata_merge_on_concat_fields Country,Year,TitleDisambiguation -OIDtype assigned -OIDmetadata Identifier" \
    -plugin JSONSPARQLResultPlugin  \
    $tmp_cache/sparqlresults-$f

if [ $? != 0 ] ; then
    echo "Error encountered when exploding:" 1>&2
    echo "  $tmp_cache/sparqlresults-$f" 1>&2
    exit 1
fi


echo ""
echo "Regenerating sparqlresults-* files in '../import' (from exploded results in '$tmp_cache')"

##/bin/rm -rf ../import/sparqlresults-*

for d in $tmp_cache/sparqlresults-* ; do
    tail_d=${d##*/}
    cat $tmp_cache/$tail_d/metadata.xml \
	| sed 's/"accumuate"/"override"/' > ../import/$tail_d/metadata-esc-mir-gold.xml    
done

/bin/rm $tmp_cache/sparqlresults-*


#/bin/mv $tmp_cache/sparqlresults-*/*.xml ../import/.

echo ""
